@@ -58,12 +58,12 @@ class OperatingPoint(AeroSandboxObject):
         """
 
         alpha_rotation = np.rotation_matrix_3D(
-            angle=np.radians(self.alpha),
+            angle=np.radians(-self.alpha),
             axis=np.array([0, 1, 0]),
             _axis_already_normalized=True
         )
         beta_rotation = np.rotation_matrix_3D(
-            angle=np.radians(self.beta),
+            angle=np.radians(-self.beta),
             axis=np.array([0, 0, 1]),
             _axis_already_normalized=True
         )
@@ -98,11 +98,11 @@ class OperatingPoint(AeroSandboxObject):
         a = angular_velocity_vector_geometry_axes
         b = points
 
-        rotation_velocity_geometry_axes = np.array([
+        rotation_velocity_geometry_axes = np.transpose(np.array([
             a[1] * b[:, 2] - a[2] * b[:, 1],
             a[2] * b[:, 0] - a[0] * b[:, 2],
             a[0] * b[:, 1] - a[1] * b[:, 0]
-        ])
+        ]))
 
         rotation_velocity_geometry_axes = -rotation_velocity_geometry_axes  # negative sign, since we care about the velocity the WING SEES, not the velocity of the wing.
 
